# API Reference

## Functions

::: lightshap.explain_tree
    options:
      show_root_heading: true
      heading_level: 3

::: lightshap.explain_any
    options:
      show_root_heading: true
      heading_level: 3

## Classes

::: lightshap.Explanation
    options:
      show_root_heading: true
      heading_level: 3
      members_order: source
